aboutsummaryrefslogtreecommitdiff
path: root/fs/sdcardfs/inode.c
diff options
context:
space:
mode:
authorAlex Shi <alex.shi@linaro.org>2017-01-19 22:49:17 +0800
committerAlex Shi <alex.shi@linaro.org>2017-01-19 22:49:17 +0800
commitd661f15677f5205c1d272c2db90b60b2d56b25dd (patch)
treede3654c1be908381cbe1e46d8ff1afd447851330 /fs/sdcardfs/inode.c
parent659a75a439d055cc48086afc2e101ca6ad8343a4 (diff)
parent65117109f6344fa46542f85844bc292842116192 (diff)
Merge branch 'lsk-v4.1-android' of git://android.git.linaro.org/kernel/linaro-android into linux-linaro-lsk-v4.1-androidlsk-v4.1-17.02-android
Diffstat (limited to 'fs/sdcardfs/inode.c')
-rw-r--r--fs/sdcardfs/inode.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/fs/sdcardfs/inode.c b/fs/sdcardfs/inode.c
index 17435631ca1f..878546ff78b2 100644
--- a/fs/sdcardfs/inode.c
+++ b/fs/sdcardfs/inode.c
@@ -639,11 +639,11 @@ static int sdcardfs_setattr(struct dentry *dentry, struct iattr *ia)
inode = d_inode(dentry);
/*
* Check if user has permission to change inode. We don't check if
* this user can change the lower inode: that should happen when
* calling notify_change on the lower inode.
*/
- err = inode_change_ok(inode, ia);
+ err = setattr_prepare(dentry, ia);
/* no vfs_XXX operations required, cred overriding will be skipped. wj*/
if (!err) {
@@ -639,11 +639,11 @@ static int sdcardfs_setattr(struct dentry *dentry, struct iattr *ia)
inode = d_inode(dentry);
/*
- * Check if user has permission to change inode. We don't check if
+ * Check if user has permission to change dentry. We don't check if
* this user can change the lower inode: that should happen when
* calling notify_change on the lower inode.